Ported from juno atom_table for the Hermes Rust lexer; carries encapsulated unsafe; adds a byte/WTF-8 intern path.
Structs
- Atom
- This represents a unique string index in the table.
- Atom
Bytes - This represents a unique byte-string index in the table. The bytes need not be valid UTF-8.
- Atom
Table - A string uniquing table - only one copy of a string is stored and all attempts to add the same string again return the same atom. This table is intended to be easily shareable, so it utilizes interior mutability. UnsafeCell<> is safe because we never allow reference to it to escape.
- AtomU16
- This represents a unique string index in the table.
Constants
- INVALID_
ATOM - A special value reserved for the invalid atom.
- INVALID_
ATOM_ BYTES - A special value reserved for the invalid atom bytes.